[Pkg-privacy-commits] [nautilus-wipe] 166/224: Consistently use the "NW" prefix for each file name and exported API
Ulrike Uhlig
u-guest at moszumanska.debian.org
Thu Jul 7 19:45:46 UTC 2016
This is an automated email from the git hooks/post-receive script.
u-guest pushed a commit to branch master
in repository nautilus-wipe.
commit 0e6ccf59d4b104911e212be0fb2868f8ec6ec7fc
Author: Colomban Wendling <ban at herbesfolles.org>
Date: Mon May 21 18:47:39 2012 +0200
Consistently use the "NW" prefix for each file name and exported API
---
configure.ac | 2 +-
nautilus-wipe/Makefile.am | 28 +-
nautilus-wipe/delete-operation.h | 63 -----
nautilus-wipe/extension.c | 4 +-
nautilus-wipe/fill-operation.h | 71 -----
nautilus-wipe/{compat.h => nw-compat.h} | 4 +-
.../{delete-operation.c => nw-delete-operation.c} | 28 +-
nautilus-wipe/nw-delete-operation.h | 63 +++++
nautilus-wipe/{nautilus-wipe.c => nw-extension.c} | 109 ++++----
nautilus-wipe/{nautilus-wipe.h => nw-extension.h} | 42 +--
.../{fill-operation.c => nw-fill-operation.c} | 100 +++----
nautilus-wipe/nw-fill-operation.h | 71 +++++
...{operation-manager.c => nw-operation-manager.c} | 76 +++---
nautilus-wipe/nw-operation-manager.h | 73 ++++++
nautilus-wipe/{path-list.c => nw-path-list.c} | 18 +-
nautilus-wipe/{path-list.h => nw-path-list.h} | 12 +-
.../{progress-dialog.c => nw-progress-dialog.c} | 288 ++++++++++-----------
nautilus-wipe/nw-progress-dialog.h | 96 +++++++
nautilus-wipe/{type-utils.h => nw-type-utils.h} | 26 +-
nautilus-wipe/operation-manager.h | 73 ------
nautilus-wipe/progress-dialog.h | 96 -------
po/POTFILES.in | 8 +-
22 files changed, 674 insertions(+), 677 deletions(-)
diff --git a/configure.ac b/configure.ac
index 84a6357..fd27b76 100644
--- a/configure.ac
+++ b/configure.ac
@@ -2,7 +2,7 @@
AC_PREREQ([2.64])
AC_INIT([nautilus-wipe],[0.1.1])
-AC_CONFIG_SRCDIR([nautilus-wipe/nautilus-wipe.h])
+AC_CONFIG_SRCDIR([nautilus-wipe/nw-extension.h])
AC_CONFIG_AUX_DIR([build/aux])
AC_CONFIG_MACRO_DIR([build/m4])
AM_INIT_AUTOMAKE([1.11.1 -Wall -Werror foreign])
diff --git a/nautilus-wipe/Makefile.am b/nautilus-wipe/Makefile.am
index dac8ac9..20aaf18 100644
--- a/nautilus-wipe/Makefile.am
+++ b/nautilus-wipe/Makefile.am
@@ -5,20 +5,20 @@ nautilus_extension_LTLIBRARIES = libnautilus-wipe.la
localedir = $(datadir)/locale
libnautilus_wipe_la_SOURCES = extension.c \
- nautilus-wipe.c \
- nautilus-wipe.h \
- operation-manager.c \
- operation-manager.h \
- delete-operation.c \
- delete-operation.h \
- fill-operation.c \
- fill-operation.h \
- path-list.c \
- path-list.h \
- progress-dialog.c \
- progress-dialog.h \
- type-utils.h \
- compat.h
+ nw-compat.h \
+ nw-delete-operation.c \
+ nw-delete-operation.h \
+ nw-extension.c \
+ nw-extension.h \
+ nw-fill-operation.c \
+ nw-fill-operation.h \
+ nw-operation-manager.c \
+ nw-operation-manager.h \
+ nw-path-list.c \
+ nw-path-list.h \
+ nw-progress-dialog.c \
+ nw-progress-dialog.h \
+ nw-type-utils.h
libnautilus_wipe_la_CPPFLAGS = -DG_LOG_DOMAIN=\"$(PACKAGE)\" \
-DLOCALEDIR=\"$(localedir)\"
libnautilus_wipe_la_CFLAGS = @GLIB_CFLAGS@ \
diff --git a/nautilus-wipe/delete-operation.h b/nautilus-wipe/delete-operation.h
deleted file mode 100644
index 0ff391a..0000000
--- a/nautilus-wipe/delete-operation.h
+++ /dev/null
@@ -1,63 +0,0 @@
-/*
- * nautilus-wipe - a nautilus extension to wipe file(s)
- *
- * Copyright (C) 2009-2011 Colomban Wendling <ban at herbesfolles.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- */
-
-#ifndef NAUTILUS_WIPE_DELETE_OPERATION_H
-#define NAUTILUS_WIPE_DELETE_OPERATION_H
-
-#include <glib.h>
-#include <glib-object.h>
-#include <gsecuredelete/gsecuredelete.h>
-
-G_BEGIN_DECLS
-
-
-/**
- * NautilusWipeDeleteOperationError:
- * @NAUTILUS_WIPE_DELETE_OPERATION_ERROR_FAILED: An error occurred
- *
- * Possible errors from the %NAUTILUS_WIPE_DELETE_OPERATION_ERROR domain.
- */
-typedef enum
-{
- NAUTILUS_WIPE_DELETE_OPERATION_ERROR_FAILED
-} NautilusWipeDeleteOperationError;
-
-/**
- * NAUTILUS_WIPE_DELETE_OPERATION_ERROR:
- *
- * Domain for error coming from a NautilusWipe's delete operation.
- */
-#define NAUTILUS_WIPE_DELETE_OPERATION_ERROR (nautilus_wipe_delete_operation_error_quark ())
-
-GQuark nautilus_wipe_delete_operation_error_quark (void) G_GNUC_CONST;
-GsdAsyncOperation *nautilus_wipe_delete_operation (GList *files,
- gboolean fast,
- GsdSecureDeleteOperationMode mode,
- gboolean zeroise,
- GCallback finished_handler,
- GCallback progress_handler,
- gpointer data,
- GError **error);
-
-
-G_END_DECLS
-
-#endif /* guard */
diff --git a/nautilus-wipe/extension.c b/nautilus-wipe/extension.c
index a658dff..9524f57 100644
--- a/nautilus-wipe/extension.c
+++ b/nautilus-wipe/extension.c
@@ -25,7 +25,7 @@
# include "config.h"
#endif
-#include "nautilus-wipe.h"
+#include "nw-extension.h"
#include <glib.h>
#include <glib/gi18n-lib.h>
@@ -40,7 +40,7 @@ nautilus_module_initialize (GTypeModule *module)
{
g_message ("Initializing");
bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
- provider_types[0] = nautilus_wipe_register_type (module);
+ provider_types[0] = nw_extension_register_type (module);
}
/* extension points types registration */
diff --git a/nautilus-wipe/fill-operation.h b/nautilus-wipe/fill-operation.h
deleted file mode 100644
index 7fc0c20..0000000
--- a/nautilus-wipe/fill-operation.h
+++ /dev/null
@@ -1,71 +0,0 @@
-/*
- * nautilus-wipe - a nautilus extension to wipe file(s)
- *
- * Copyright (C) 2009-2011 Colomban Wendling <ban at herbesfolles.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- */
-
-#ifndef NAUTILUS_WIPE_FILL_OPERATION_H
-#define NAUTILUS_WIPE_FILL_OPERATION_H
-
-#include <glib.h>
-#include <glib-object.h>
-#include <gsecuredelete/gsecuredelete.h>
-
-G_BEGIN_DECLS
-
-
-/**
- * NautilusWipeFillOperationError:
- * @NAUTILUS_WIPE_FILL_OPERATION_ERROR_MISSING_MOUNT: A file have no mount
- * @NAUTILUS_WIPE_FILL_OPERATION_ERROR_REMOTE_MOUNT: A mount is not local
- * @NAUTILUS_WIPE_FILL_OPERATION_ERROR_FAILED: An error occurred
- *
- * Possible errors from the %NAUTILUS_WIPE_FILL_OPERATION_ERROR domain.
- */
-typedef enum
-{
- NAUTILUS_WIPE_FILL_OPERATION_ERROR_MISSING_MOUNT,
- NAUTILUS_WIPE_FILL_OPERATION_ERROR_REMOTE_MOUNT,
- NAUTILUS_WIPE_FILL_OPERATION_ERROR_FAILED
-} NautilusWipeFillOperationError;
-
-/**
- * NAUTILUS_WIPE_FILL_OPERATION_ERROR:
- *
- * Domain for error coming from a NautilusWipe's fill operation.
- */
-#define NAUTILUS_WIPE_FILL_OPERATION_ERROR (nautilus_wipe_fill_operation_error_quark ())
-
-GQuark nautilus_wipe_fill_operation_error_quark (void) G_GNUC_CONST;
-gboolean nautilus_wipe_fill_operation_filter_files (GList *paths,
- GList **work_paths_,
- GList **work_mounts_,
- GError **error);
-GsdAsyncOperation *nautilus_wipe_fill_operation (GList *files,
- gboolean fast,
- GsdSecureDeleteOperationMode mode,
- gboolean zeroise,
- GCallback finished_handler,
- GCallback progress_handler,
- gpointer data,
- GError **error);
-
-
-G_END_DECLS
-
-#endif /* guard */
diff --git a/nautilus-wipe/compat.h b/nautilus-wipe/nw-compat.h
similarity index 98%
rename from nautilus-wipe/compat.h
rename to nautilus-wipe/nw-compat.h
index 9ebb6fd..9731417 100644
--- a/nautilus-wipe/compat.h
+++ b/nautilus-wipe/nw-compat.h
@@ -21,8 +21,8 @@
/* Contains compatibility things for old GLib, GTK and Nautilus */
-#ifndef NAUTILUS_WIPE_COMPAT_H
-#define NAUTILUS_WIPE_COMPAT_H
+#ifndef NW_COMPAT_H
+#define NW_COMPAT_H
#ifdef HAVE_CONFIG_H
# include "config.h"
diff --git a/nautilus-wipe/delete-operation.c b/nautilus-wipe/nw-delete-operation.c
similarity index 79%
rename from nautilus-wipe/delete-operation.c
rename to nautilus-wipe/nw-delete-operation.c
index c2c74d6..2c22f35 100644
--- a/nautilus-wipe/delete-operation.c
+++ b/nautilus-wipe/nw-delete-operation.c
@@ -23,7 +23,7 @@
# include "config.h"
#endif
-#include "delete-operation.h"
+#include "nw-delete-operation.h"
#include <glib.h>
#include <glib/gi18n-lib.h>
@@ -33,12 +33,12 @@
GQuark
-nautilus_wipe_delete_operation_error_quark (void)
+nw_delete_operation_error_quark (void)
{
static volatile gsize quark = 0;
if (g_once_init_enter (&quark)) {
- GQuark q = g_quark_from_static_string ("NautilusWipeDeleteOperationError");
+ GQuark q = g_quark_from_static_string ("NwDeleteOperationError");
g_once_init_leave (&quark, q);
}
@@ -47,7 +47,7 @@ nautilus_wipe_delete_operation_error_quark (void)
}
/*
- * nautilus_wipe_delete_operation:
+ * nw_delete_operation:
* @files: A list of paths to delete.
* @fast: The Gsd.SecureDeleteOperation:fast setting
* @mode: The Gsd.SecureDeleteOperation:mode setting
@@ -65,14 +65,14 @@ nautilus_wipe_delete_operation_error_quark (void)
* no longer needed.
*/
GsdAsyncOperation *
-nautilus_wipe_delete_operation (GList *files,
- gboolean fast,
- GsdSecureDeleteOperationMode mode,
- gboolean zeroise,
- GCallback finished_handler,
- GCallback progress_handler,
- gpointer data,
- GError **error)
+nw_delete_operation (GList *files,
+ gboolean fast,
+ GsdSecureDeleteOperationMode mode,
+ gboolean zeroise,
+ GCallback finished_handler,
+ GCallback progress_handler,
+ gpointer data,
+ GError **error)
{
gboolean success = TRUE;
GsdDeleteOperation *operation;
@@ -85,8 +85,8 @@ nautilus_wipe_delete_operation (GList *files,
}
if (n_files < 1) {
g_set_error (error,
- NAUTILUS_WIPE_DELETE_OPERATION_ERROR,
- NAUTILUS_WIPE_DELETE_OPERATION_ERROR_FAILED,
+ NW_DELETE_OPERATION_ERROR,
+ NW_DELETE_OPERATION_ERROR_FAILED,
_("Nothing to do!"));
success = FALSE;
} else {
diff --git a/nautilus-wipe/nw-delete-operation.h b/nautilus-wipe/nw-delete-operation.h
new file mode 100644
index 0000000..97e0e7b
--- /dev/null
+++ b/nautilus-wipe/nw-delete-operation.h
@@ -0,0 +1,63 @@
+/*
+ * nautilus-wipe - a nautilus extension to wipe file(s)
+ *
+ * Copyright (C) 2009-2011 Colomban Wendling <ban at herbesfolles.org>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public
+ * License as published by the Free Software Foundation; either
+ * version 3 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public
+ * License along with this library; if not, write to the Free
+ * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ */
+
+#ifndef NW_DELETE_OPERATION_H
+#define NW_DELETE_OPERATION_H
+
+#include <glib.h>
+#include <glib-object.h>
+#include <gsecuredelete/gsecuredelete.h>
+
+G_BEGIN_DECLS
+
+
+/**
+ * NwDeleteOperationError:
+ * @NW_DELETE_OPERATION_ERROR_FAILED: An error occurred
+ *
+ * Possible errors from the %NW_DELETE_OPERATION_ERROR domain.
+ */
+typedef enum
+{
+ NW_DELETE_OPERATION_ERROR_FAILED
+} NwDeleteOperationError;
+
+/**
+ * NW_DELETE_OPERATION_ERROR:
+ *
+ * Domain for error coming from a NautilusWipe's delete operation.
+ */
+#define NW_DELETE_OPERATION_ERROR (nw_delete_operation_error_quark ())
+
+GQuark nw_delete_operation_error_quark (void) G_GNUC_CONST;
+GsdAsyncOperation *nw_delete_operation (GList *files,
+ gboolean fast,
+ GsdSecureDeleteOperationMode mode,
+ gboolean zeroise,
+ GCallback finished_handler,
+ GCallback progress_handler,
+ gpointer data,
+ GError **error);
+
+
+G_END_DECLS
+
+#endif /* guard */
diff --git a/nautilus-wipe/nautilus-wipe.c b/nautilus-wipe/nw-extension.c
similarity index 74%
rename from nautilus-wipe/nautilus-wipe.c
rename to nautilus-wipe/nw-extension.c
index 66d60a0..2b61e64 100644
--- a/nautilus-wipe/nautilus-wipe.c
+++ b/nautilus-wipe/nw-extension.c
@@ -23,7 +23,7 @@
# include "config.h"
#endif
-#include "nautilus-wipe.h"
+#include "nw-extension.h"
#include <libnautilus-extension/nautilus-menu-provider.h>
#include <libnautilus-extension/nautilus-file-info.h>
@@ -35,37 +35,37 @@
#include <gsecuredelete/gsecuredelete.h>
-#include "path-list.h"
-#include "operation-manager.h"
-#include "delete-operation.h"
-#include "fill-operation.h"
-#include "compat.h"
-#include "type-utils.h"
+#include "nw-path-list.h"
+#include "nw-operation-manager.h"
+#include "nw-delete-operation.h"
+#include "nw-fill-operation.h"
+#include "nw-compat.h"
+#include "nw-type-utils.h"
/* private prototypes */
-static GList *nautilus_wipe_real_get_file_items (NautilusMenuProvider *provider,
+static GList *nw_extension_real_get_file_items (NautilusMenuProvider *provider,
GtkWidget *window,
GList *files);
-static GList *nautilus_wipe_real_get_background_items (NautilusMenuProvider *provider,
+static GList *nw_extension_real_get_background_items (NautilusMenuProvider *provider,
GtkWidget *window,
NautilusFileInfo *current_folder);
-static void nautilus_wipe_menu_provider_iface_init (NautilusMenuProviderIface *iface);
+static void nw_extension_menu_provider_iface_init (NautilusMenuProviderIface *iface);
-#define ITEM_DATA_MOUNTPOINTS_KEY "NautilusWipe::mountpoints"
-#define ITEM_DATA_PATHS_KEY "NautilusWipe::paths"
-#define ITEM_DATA_WINDOW_KEY "NautilusWipe::parent-window"
+#define ITEM_DATA_MOUNTPOINTS_KEY "Nw::Extension::mountpoints"
+#define ITEM_DATA_PATHS_KEY "Nw::Extension::paths"
+#define ITEM_DATA_WINDOW_KEY "Nw::Extension::parent-window"
GQuark
-nautilus_wipe_error_quark (void)
+nw_extension_error_quark (void)
{
static volatile gsize quark = 0;
if (g_once_init_enter (&quark)) {
- GQuark q = g_quark_from_static_string ("NautilusWipeError");
+ GQuark q = g_quark_from_static_string ("NwExtensionError");
g_once_init_leave (&quark, q);
}
@@ -73,35 +73,35 @@ nautilus_wipe_error_quark (void)
return (GQuark) quark;
}
-NAUTILUS_WIPE_DEFINE_TYPE_MODULE_WITH_CODE (NautilusWipe,
- nautilus_wipe,
- G_TYPE_OBJECT,
- NAUTILUS_WIPE_TYPE_MODULE_IMPLEMENT_INTERFACE (NAUTILUS_TYPE_MENU_PROVIDER,
- nautilus_wipe_menu_provider_iface_init))
+NW_DEFINE_TYPE_MODULE_WITH_CODE (NwExtension,
+ nw_extension,
+ G_TYPE_OBJECT,
+ NW_TYPE_MODULE_IMPLEMENT_INTERFACE (NAUTILUS_TYPE_MENU_PROVIDER,
+ nw_extension_menu_provider_iface_init))
static void
-nautilus_wipe_menu_provider_iface_init (NautilusMenuProviderIface *iface)
+nw_extension_menu_provider_iface_init (NautilusMenuProviderIface *iface)
{
- iface->get_file_items = nautilus_wipe_real_get_file_items;
- iface->get_background_items = nautilus_wipe_real_get_background_items;
+ iface->get_file_items = nw_extension_real_get_file_items;
+ iface->get_background_items = nw_extension_real_get_background_items;
}
static void
-nautilus_wipe_class_init (NautilusWipeClass *class)
+nw_extension_class_init (NwExtensionClass *class)
{
}
static void
-nautilus_wipe_init (NautilusWipe *self)
+nw_extension_init (NwExtension *self)
{
}
/* Runs the wipe operation */
static void
-nautilus_wipe_run_delete_operation (GtkWindow *parent,
- GList *files)
+nw_extension_run_delete_operation (GtkWindow *parent,
+ GList *files)
{
gchar *confirm_primary_text = NULL;
guint n_items;
@@ -120,7 +120,7 @@ nautilus_wipe_run_delete_operation (GtkWindow *parent,
name);
g_free (name);
}
- nautilus_wipe_operation_manager_run (
+ nw_operation_manager_run (
parent, files,
/* confirm dialog */
confirm_primary_text,
@@ -130,7 +130,7 @@ nautilus_wipe_run_delete_operation (GtkWindow *parent,
/* progress dialog */
_("Wiping files..."),
/* operation launcher */
- nautilus_wipe_delete_operation,
+ nw_delete_operation,
/* failed dialog */
_("Wipe failed."),
/* success dialog */
@@ -142,9 +142,9 @@ nautilus_wipe_run_delete_operation (GtkWindow *parent,
/* Runs the fill operation */
static void
-nautilus_wipe_run_fill_operation (GtkWindow *parent,
- GList *paths,
- GList *mountpoints)
+nw_extension_run_fill_operation (GtkWindow *parent,
+ GList *paths,
+ GList *mountpoints)
{
gchar *confirm_primary_text = NULL;
gchar *success_secondary_text = NULL;
@@ -196,7 +196,7 @@ nautilus_wipe_run_fill_operation (GtkWindow *parent,
name);
g_free (name);
}
- nautilus_wipe_operation_manager_run (
+ nw_operation_manager_run (
parent, paths,
/* confirm dialog */
confirm_primary_text,
@@ -206,7 +206,7 @@ nautilus_wipe_run_fill_operation (GtkWindow *parent,
/* progress dialog */
_("Wiping available diskspace..."),
/* operation launcher */
- nautilus_wipe_fill_operation,
+ nw_fill_operation,
/* failed dialog */
_("Wipe failed"),
/* success dialog */
@@ -222,8 +222,8 @@ static void
wipe_menu_item_activate_handler (GObject *item,
gpointer data)
{
- nautilus_wipe_run_delete_operation (g_object_get_data (item, ITEM_DATA_WINDOW_KEY),
- g_object_get_data (item, ITEM_DATA_PATHS_KEY));
+ nw_extension_run_delete_operation (g_object_get_data (item, ITEM_DATA_WINDOW_KEY),
+ g_object_get_data (item, ITEM_DATA_PATHS_KEY));
}
static NautilusMenuItem *
@@ -240,8 +240,8 @@ create_wipe_menu_item (NautilusMenuProvider *provider,
GTK_STOCK_DELETE);
g_object_set_data (G_OBJECT (item), ITEM_DATA_WINDOW_KEY, window);
g_object_set_data_full (G_OBJECT (item), ITEM_DATA_PATHS_KEY,
- nautilus_wipe_path_list_copy (paths),
- (GDestroyNotify) nautilus_wipe_path_list_free);
+ nw_path_list_copy (paths),
+ (GDestroyNotify) nw_path_list_free);
g_signal_connect (item, "activate",
G_CALLBACK (wipe_menu_item_activate_handler), NULL);
@@ -252,9 +252,9 @@ static void
fill_menu_item_activate_handler (GObject *item,
gpointer data)
{
- nautilus_wipe_run_fill_operation (g_object_get_data (item, ITEM_DATA_WINDOW_KEY),
- g_object_get_data (item, ITEM_DATA_PATHS_KEY),
- g_object_get_data (item, ITEM_DATA_MOUNTPOINTS_KEY));
+ nw_extension_run_fill_operation (g_object_get_data (item, ITEM_DATA_WINDOW_KEY),
+ g_object_get_data (item, ITEM_DATA_PATHS_KEY),
+ g_object_get_data (item, ITEM_DATA_MOUNTPOINTS_KEY));
}
static NautilusMenuItem *
@@ -268,8 +268,7 @@ create_fill_menu_item (NautilusMenuProvider *provider,
GList *folders = NULL;
GError *err = NULL;
- if (! nautilus_wipe_fill_operation_filter_files (files, &folders,
- &mountpoints, &err)) {
+ if (! nw_fill_operation_filter_files (files, &folders, &mountpoints, &err)) {
g_warning (_("File filtering failed: %s"), err->message);
g_error_free (err);
} else {
@@ -280,10 +279,10 @@ create_fill_menu_item (NautilusMenuProvider *provider,
g_object_set_data (G_OBJECT (item), ITEM_DATA_WINDOW_KEY, window);
g_object_set_data_full (G_OBJECT (item), ITEM_DATA_PATHS_KEY,
folders,
- (GDestroyNotify) nautilus_wipe_path_list_free);
+ (GDestroyNotify) nw_path_list_free);
g_object_set_data_full (G_OBJECT (item), ITEM_DATA_MOUNTPOINTS_KEY,
mountpoints,
- (GDestroyNotify) nautilus_wipe_path_list_free);
+ (GDestroyNotify) nw_path_list_free);
g_signal_connect (item, "activate",
G_CALLBACK (fill_menu_item_activate_handler), NULL);
}
@@ -303,14 +302,14 @@ create_fill_menu_item (NautilusMenuProvider *provider,
/* populates Nautilus' file menu */
static GList *
-nautilus_wipe_real_get_file_items (NautilusMenuProvider *provider,
- GtkWidget *window,
- GList *files)
+nw_extension_real_get_file_items (NautilusMenuProvider *provider,
+ GtkWidget *window,
+ GList *files)
{
GList *items = NULL;
GList *paths;
- paths = nautilus_wipe_path_list_new_from_nfi_list (files);
+ paths = nw_path_list_new_from_nfi_list (files);
if (paths) {
ADD_ITEM (items, create_wipe_menu_item (provider,
"nautilus-wipe::files-items::wipe",
@@ -319,27 +318,27 @@ nautilus_wipe_real_get_file_items (NautilusMenuProvider *provider,
"nautilus-wipe::files-items::fill",
window, paths));
}
- nautilus_wipe_path_list_free (paths);
+ nw_path_list_free (paths);
return items;
}
/* populates Nautilus' background menu */
static GList *
-nautilus_wipe_real_get_background_items (NautilusMenuProvider *provider,
- GtkWidget *window,
- NautilusFileInfo *current_folder)
+nw_extension_real_get_background_items (NautilusMenuProvider *provider,
+ GtkWidget *window,
+ NautilusFileInfo *current_folder)
{
GList *items = NULL;
GList *paths = NULL;
- paths = g_list_append (paths, nautilus_wipe_path_from_nfi (current_folder));
+ paths = g_list_append (paths, nw_path_from_nfi (current_folder));
if (paths && paths->data) {
ADD_ITEM (items, create_fill_menu_item (provider,
"nautilus-wipe::background-items::fill",
window, paths));
}
- nautilus_wipe_path_list_free (paths);
+ nw_path_list_free (paths);
return items;
}
diff --git a/nautilus-wipe/nautilus-wipe.h b/nautilus-wipe/nw-extension.h
similarity index 52%
rename from nautilus-wipe/nautilus-wipe.h
rename to nautilus-wipe/nw-extension.h
index 8130808..7769269 100644
--- a/nautilus-wipe/nautilus-wipe.h
+++ b/nautilus-wipe/nw-extension.h
@@ -19,8 +19,8 @@
*
*/
-#ifndef NAUTILUS_WIPE_H
-#define NAUTILUS_WIPE_H
+#ifndef NW_EXTENSION_H
+#define NW_EXTENSION_H
#include <glib.h>
#include <glib-object.h>
@@ -28,34 +28,34 @@
G_BEGIN_DECLS
-#define NAUTILUS_TYPE_WIPE (nautilus_wipe_get_type ())
-#define NAUTILUS_WIPE(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), NAUTILUS_TYPE_WIPE, NautilusWipe))
-#define NAUTILUS_IS_WIPE(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), NAUTILUS_TYPE_WIPE))
-typedef struct _NautilusWipe NautilusWipe;
-typedef struct _NautilusWipeClass NautilusWipeClass;
+#define NW_TYPE_EXTENSION (nw_extension_get_type ())
+#define NW_EXTENSION(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), NW_TYPE_EXTENSION, NwExtension))
+#define NW_IS_EXTENSION(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), NW_TYPE_EXTENSION))
+typedef struct _NwExtension NwExtension;
+typedef struct _NwExtensionClass NwExtensionClass;
-#define NAUTILUS_WIPE_ERROR (nautilus_wipe_error_quark ())
+#define NW_EXTENSION_ERROR (nw_extension_error_quark ())
typedef enum {
- NAUTILUS_WIPE_ERROR_SPAWN_FAILED,
- NAUTILUS_WIPE_ERROR_CHILD_CRASHED,
- NAUTILUS_WIPE_ERROR_CHILD_FAILED,
- NAUTILUS_WIPE_ERROR_UNSUPPORTED_LOCATION,
- NAUTILUS_WIPE_ERROR_NOT_IMPLEMENTED,
- NAUTILUS_WIPE_ERROR_FAILED
-} NautilusWipeError;
-
-struct _NautilusWipe {
+ NW_EXTENSION_ERROR_SPAWN_FAILED,
+ NW_EXTENSION_ERROR_CHILD_CRASHED,
+ NW_EXTENSION_ERROR_CHILD_FAILED,
+ NW_EXTENSION_ERROR_UNSUPPORTED_LOCATION,
+ NW_EXTENSION_ERROR_NOT_IMPLEMENTED,
+ NW_EXTENSION_ERROR_FAILED
+} NwExtensionError;
+
+struct _NwExtension {
GObject parent_slot;
};
-struct _NautilusWipeClass {
+struct _NwExtensionClass {
GObjectClass parent_slot;
};
-GType nautilus_wipe_get_type (void) G_GNUC_CONST;
-GType nautilus_wipe_register_type (GTypeModule *module);
-GQuark nautilus_wipe_error_quark (void) G_GNUC_CONST;
+GType nw_extension_get_type (void) G_GNUC_CONST;
+GType nw_extension_register_type (GTypeModule *module);
+GQuark nw_extension_error_quark (void) G_GNUC_CONST;
G_END_DECLS
diff --git a/nautilus-wipe/nw-fill-operation.h b/nautilus-wipe/nw-fill-operation.h
new file mode 100644
index 0000000..6ac56cc
--- /dev/null
+++ b/nautilus-wipe/nw-fill-operation.h
@@ -0,0 +1,71 @@
+/*
+ * nautilus-wipe - a nautilus extension to wipe file(s)
+ *
+ * Copyright (C) 2009-2011 Colomban Wendling <ban at herbesfolles.org>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public
+ * License as published by the Free Software Foundation; either
+ * version 3 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public
+ * License along with this library; if not, write to the Free
+ * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ */
+
+#ifndef NW_FILL_OPERATION_H
+#define NW_FILL_OPERATION_H
+
+#include <glib.h>
+#include <glib-object.h>
+#include <gsecuredelete/gsecuredelete.h>
+
+G_BEGIN_DECLS
+
+
+/**
+ * NwFillOperationError:
+ * @NW_FILL_OPERATION_ERROR_MISSING_MOUNT: A file have no mount
+ * @NW_FILL_OPERATION_ERROR_REMOTE_MOUNT: A mount is not local
+ * @NW_FILL_OPERATION_ERROR_FAILED: An error occurred
+ *
+ * Possible errors from the %NW_FILL_OPERATION_ERROR domain.
+ */
+typedef enum
+{
+ NW_FILL_OPERATION_ERROR_MISSING_MOUNT,
+ NW_FILL_OPERATION_ERROR_REMOTE_MOUNT,
+ NW_FILL_OPERATION_ERROR_FAILED
+} NwFillOperationError;
+
+/**
+ * NW_FILL_OPERATION_ERROR:
+ *
+ * Domain for error coming from a NautilusWipe's fill operation.
+ */
+#define NW_FILL_OPERATION_ERROR (nw_fill_operation_error_quark ())
+
+GQuark nw_fill_operation_error_quark (void) G_GNUC_CONST;
+gboolean nw_fill_operation_filter_files (GList *paths,
+ GList **work_paths_,
+ GList **work_mounts_,
+ GError **error);
+GsdAsyncOperation *nw_fill_operation (GList *files,
+ gboolean fast,
+ GsdSecureDeleteOperationMode mode,
+ gboolean zeroise,
+ GCallback finished_handler,
+ GCallback progress_handler,
+ gpointer data,
+ GError **error);
+
+
+G_END_DECLS
+
+#endif /* guard */
diff --git a/nautilus-wipe/nw-operation-manager.h b/nautilus-wipe/nw-operation-manager.h
new file mode 100644
index 0000000..54fe53b
--- /dev/null
+++ b/nautilus-wipe/nw-operation-manager.h
@@ -0,0 +1,73 @@
+/*
+ * nautilus-wipe - a nautilus extension to wipe file(s)
+ *
+ * Copyright (C) 2009-2011 Colomban Wendling <ban at herbesfolles.org>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public
+ * License as published by the Free Software Foundation; either
+ * version 3 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public
+ * License along with this library; if not, write to the Free
+ * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ */
+
+#ifndef NW_OPERATION_MANAGER_H
+#define NW_OPERATION_MANAGER_H
+
+#include <glib.h>
+#include <glib-object.h>
+#include <gtk/gtk.h>
+#include <gsecuredelete/gsecuredelete.h>
+
+G_BEGIN_DECLS
+
+
+/**
+ * NwOperationFunc:
+ * @files: Paths to work on
+ * @fast: The Gsd.SecureDeleteOperation:fast setting
+ * @mode: The Gsd.SecureDeleteOperation:mode setting
+ * @zeroise: The Gsd.ZeroableOperation:zeroise setting
+ * @finished_handler: Handler for GsdAsyncOperation::finished
+ * @progress_handler: Handler for GsdAsyncOperation::progress
+ * @data: User data for @finished_hanlder and @progress_handler
+ * @error: Return location for errors, or %NULL to ignore them
+ *
+ *
+ * Returns: The operation object that was launched, or %NULL on failure.
+ * The operation object should be unref'd with g_object_unref() when
+ * no longer needed.
+ */
+typedef GsdAsyncOperation *(*NwOperationFunc) (GList *files,
+ gboolean fast,
+ GsdSecureDeleteOperationMode mode,
+ gboolean zeroise,
+ GCallback finished_handler,
+ GCallback progress_handler,
+ gpointer data,
+ GError **error);
+
+void nw_operation_manager_run (GtkWindow *parent,
+ GList *files,
+ const gchar *confirm_primary_text,
+ const gchar *confirm_secondary_text,
+ const gchar *confirm_button_text,
+ GtkWidget *confirm_button_icon,
+ const gchar *progress_dialog_text,
+ NwOperationFunc operation_launcher_func,
+ const gchar *failed_primary_text,
+ const gchar *success_primary_text,
+ const gchar *success_secondary_text);
+
+
+G_END_DECLS
+
+#endif /* guard */
diff --git a/nautilus-wipe/path-list.h b/nautilus-wipe/nw-path-list.h
similarity index 74%
rename from nautilus-wipe/path-list.h
rename to nautilus-wipe/nw-path-list.h
index fdecef5..792e5d0 100644
--- a/nautilus-wipe/path-list.h
+++ b/nautilus-wipe/nw-path-list.h
@@ -19,8 +19,8 @@
*
*/
-#ifndef NAUTILUS_WIPE_PATH_LIST_H
-#define NAUTILUS_WIPE_PATH_LIST_H
+#ifndef NW_PATH_LIST_H
+#define NW_PATH_LIST_H
#include <glib.h>
@@ -29,10 +29,10 @@
G_BEGIN_DECLS
-gchar *nautilus_wipe_path_from_nfi (NautilusFileInfo *nfi);
-GList *nautilus_wipe_path_list_new_from_nfi_list (GList *nfis);
-void nautilus_wipe_path_list_free (GList *paths);
-GList *nautilus_wipe_path_list_copy (GList *src);
+gchar *nw_path_from_nfi (NautilusFileInfo *nfi);
+GList *nw_path_list_new_from_nfi_list (GList *nfis);
+void nw_path_list_free (GList *paths);
+GList *nw_path_list_copy (GList *src);
G_END_DECLS
diff --git a/nautilus-wipe/progress-dialog.c b/nautilus-wipe/nw-progress-dialog.c
similarity index 58%
rename from nautilus-wipe/progress-dialog.c
rename to nautilus-wipe/nw-progress-dialog.c
index 553d0a2..5ab16d7 100644
--- a/nautilus-wipe/progress-dialog.c
+++ b/nautilus-wipe/nw-progress-dialog.c
@@ -19,19 +19,19 @@
*
*/
-#include "progress-dialog.h"
+#include "nw-progress-dialog.h"
#include <stdarg.h>
#include <glib.h>
#include <gtk/gtk.h>
-#include "compat.h" /* for gtk_dialog_get_action_area(),
- * gtk_dialog_get_content_area() and
- * gtk_widget_get_sensitive() */
+#include "nw-compat.h" /* for gtk_dialog_get_action_area(),
+ * gtk_dialog_get_content_area() and
+ * gtk_widget_get_sensitive() */
-struct _NautilusWipeProgressDialogPrivate {
+struct _NwProgressDialogPrivate {
GtkLabel *label;
GtkProgressBar *progress;
GtkWidget *cancel_button;
@@ -41,7 +41,7 @@ struct _NautilusWipeProgressDialogPrivate {
gboolean auto_hide_action_area;
};
-#define GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), NAUTILUS_TYPE_WIPE_PROGRESS_DIALOG, NautilusWipeProgressDialogPrivate))
+#define GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), NW_TYPE_PROGRESS_DIALOG, NwProgressDialogPrivate))
enum
{
@@ -52,31 +52,31 @@ enum
PROP_AUTO_HIDE_ACTION_AREA
};
-G_DEFINE_TYPE (NautilusWipeProgressDialog, nautilus_wipe_progress_dialog, GTK_TYPE_DIALOG)
+G_DEFINE_TYPE (NwProgressDialog, nw_progress_dialog, GTK_TYPE_DIALOG)
static void
-nautilus_wipe_progress_dialog_set_property (GObject *obj,
- guint prop_id,
- const GValue *value,
- GParamSpec *pspec)
+nw_progress_dialog_set_property (GObject *obj,
+ guint prop_id,
+ const GValue *value,
+ GParamSpec *pspec)
{
- NautilusWipeProgressDialog *self = NAUTILUS_WIPE_PROGRESS_DIALOG (obj);
+ NwProgressDialog *self = NW_PROGRESS_DIALOG (obj);
switch (prop_id) {
case PROP_TEXT:
- nautilus_wipe_progress_dialog_set_text (self, "%s", g_value_get_string (value));
+ nw_progress_dialog_set_text (self, "%s", g_value_get_string (value));
break;
case PROP_HAS_CANCEL_BUTTON:
- nautilus_wipe_progress_dialog_set_has_cancel_button (self, g_value_get_boolean (value));
+ nw_progress_dialog_set_has_cancel_button (self, g_value_get_boolean (value));
break;
case PROP_HAS_CLOSE_BUTTON:
- nautilus_wipe_progress_dialog_set_has_close_button (self, g_value_get_boolean (value));
+ nw_progress_dialog_set_has_close_button (self, g_value_get_boolean (value));
break;
case PROP_AUTO_HIDE_ACTION_AREA:
- nautilus_wipe_progress_dialog_set_auto_hide_action_area (self, g_value_get_boolean (value));
+ nw_progress_dialog_set_auto_hide_action_area (self, g_value_get_boolean (value));
break;
default:
@@ -85,28 +85,28 @@ nautilus_wipe_progress_dialog_set_property (GObject *obj,
}
static void
-nautilus_wipe_progress_dialog_get_property (GObject *obj,
- guint prop_id,
- GValue *value,
- GParamSpec *pspec)
+nw_progress_dialog_get_property (GObject *obj,
+ guint prop_id,
+ GValue *value,
+ GParamSpec *pspec)
{
- NautilusWipeProgressDialog *self = NAUTILUS_WIPE_PROGRESS_DIALOG (obj);
+ NwProgressDialog *self = NW_PROGRESS_DIALOG (obj);
switch (prop_id) {
case PROP_TEXT:
- g_value_set_string (value, nautilus_wipe_progress_dialog_get_text (self));
+ g_value_set_string (value, nw_progress_dialog_get_text (self));
break;
case PROP_HAS_CANCEL_BUTTON:
- g_value_set_boolean (value, nautilus_wipe_progress_dialog_get_has_cancel_button (self));
+ g_value_set_boolean (value, nw_progress_dialog_get_has_cancel_button (self));
break;
case PROP_HAS_CLOSE_BUTTON:
- g_value_set_boolean (value, nautilus_wipe_progress_dialog_get_has_close_button (self));
+ g_value_set_boolean (value, nw_progress_dialog_get_has_close_button (self));
break;
case PROP_AUTO_HIDE_ACTION_AREA:
- g_value_set_boolean (value, nautilus_wipe_progress_dialog_get_auto_hide_action_area (self));
+ g_value_set_boolean (value, nw_progress_dialog_get_auto_hide_action_area (self));
break;
default:
@@ -115,10 +115,10 @@ nautilus_wipe_progress_dialog_get_property (GObject *obj,
}
static void
-nautilus_wipe_progress_dialog_response (GtkDialog *dialog,
- gint response_id)
+nw_progress_dialog_response (GtkDialog *dialog,
+ gint response_id)
{
- NautilusWipeProgressDialog *self = NAUTILUS_WIPE_PROGRESS_DIALOG (dialog);
+ NwProgressDialog *self = NW_PROGRESS_DIALOG (dialog);
if (GTK_IS_WIDGET (self->priv->cancel_button)) {
gtk_widget_set_sensitive (self->priv->cancel_button,
@@ -129,14 +129,14 @@ nautilus_wipe_progress_dialog_response (GtkDialog *dialog,
self->priv->finished || self->priv->canceled);
}
- if (GTK_DIALOG_CLASS (nautilus_wipe_progress_dialog_parent_class)->response) {
- GTK_DIALOG_CLASS (nautilus_wipe_progress_dialog_parent_class)->response (dialog, response_id);
+ if (GTK_DIALOG_CLASS (nw_progress_dialog_parent_class)->response) {
+ GTK_DIALOG_CLASS (nw_progress_dialog_parent_class)->response (dialog, response_id);
}
}
static void
-update_action_area_visibility (NautilusWipeProgressDialog *dialog,
- gboolean force_show)
+update_action_area_visibility (NwProgressDialog *dialog,
+ gboolean force_show)
{
if (dialog->priv->auto_hide_action_area || force_show) {
GtkWidget *container;
@@ -162,7 +162,7 @@ update_action_area_visibility (NautilusWipeProgressDialog *dialog,
}
static void
-nautilus_wipe_progress_dialog_init (NautilusWipeProgressDialog *self)
+nw_progress_dialog_init (NwProgressDialog *self)
{
GtkWidget *content_area;
GtkWidget *vbox;
@@ -193,40 +193,40 @@ nautilus_wipe_progress_dialog_init (NautilusWipeProgressDialog *self)
}
static void
-nautilus_wipe_progress_dialog_finalize (GObject *obj)
+nw_progress_dialog_finalize (GObject *obj)
{
- NautilusWipeProgressDialog *self = NAUTILUS_WIPE_PROGRESS_DIALOG (obj);
+ NwProgressDialog *self = NW_PROGRESS_DIALOG (obj);
- G_OBJECT_CLASS (nautilus_wipe_progress_dialog_parent_class)->finalize (obj);
+ G_OBJECT_CLASS (nw_progress_dialog_parent_class)->finalize (obj);
}
static gboolean
-nautilus_wipe_progress_dialog_delete_event (GtkWidget *widget,
- /* The doc says GdkEvent but it is
- * actually GdkEventAny. Nothing
- * bad as it is a sort of "base
- * class" for all other events.
- * See the doc. */
- GdkEventAny *event)
+nw_progress_dialog_delete_event (GtkWidget *widget,
+ /* The doc says GdkEvent but it is
+ * actually GdkEventAny. Nothing
+ * bad as it is a sort of "base
+ * class" for all other events.
+ * See the doc. */
+ GdkEventAny *event)
{
return TRUE;
}
static void
-nautilus_wipe_progress_dialog_class_init (NautilusWipeProgressDialogClass *klass)
+nw_progress_dialog_class_init (NwProgressDialogClass *klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
GtkDialogClass *dialog_class = GTK_DIALOG_CLASS (klass);
GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
- object_class->set_property = nautilus_wipe_progress_dialog_set_property;
- object_class->get_property = nautilus_wipe_progress_dialog_get_property;
- object_class->finalize = nautilus_wipe_progress_dialog_finalize;
- dialog_class->response = nautilus_wipe_progress_dialog_response;
+ object_class->set_property = nw_progress_dialog_set_property;
+ object_class->get_property = nw_progress_dialog_get_property;
+ object_class->finalize = nw_progress_dialog_finalize;
+ dialog_class->response = nw_progress_dialog_response;
/* our default handler prevent the dialog to be destroyed if the user tries to
* close the dialog. This doesn't prevent the DELETE_EVENT response to be
* triggered */
- widget_class->delete_event = nautilus_wipe_progress_dialog_delete_event;
+ widget_class->delete_event = nw_progress_dialog_delete_event;
g_object_class_install_property (object_class, PROP_TEXT,
g_param_spec_string ("text",
@@ -256,28 +256,28 @@ nautilus_wipe_progress_dialog_class_init (NautilusWipeProgressDialogClass *klass
FALSE,
G_PARAM_READWRITE));
- g_type_class_add_private (klass, sizeof (NautilusWipeProgressDialogPrivate));
+ g_type_class_add_private (klass, sizeof (NwProgressDialogPrivate));
}
/**
- * nautilus_wipe_progress_dialog_new:
+ * nw_progress_dialog_new:
* @parent: The parent window for the dialog, or %NULL for none
* @flags: Some #GtkDialogFlags or 0
* @format: format for the dialog's text
* @...: printf-like argument for @format.
*
- * Creates a new NautilusWipeProgressDialog.
+ * Creates a new NwProgressDialog.
* For the @format and @... arguments, see
- * nautilus_wipe_progress_dialog_set_text().
+ * nw_progress_dialog_set_text().
*
* Returns: The newly created dialog.
*/
GtkWidget *
-nautilus_wipe_progress_dialog_new (GtkWindow *parent,
- GtkDialogFlags flags,
- const gchar *format,
- ...)
+nw_progress_dialog_new (GtkWindow *parent,
+ GtkDialogFlags flags,
+ const gchar *format,
+ ...)
{
GtkWidget *self;
gchar *text;
@@ -286,7 +286,7 @@ nautilus_wipe_progress_dialog_new (GtkWindow *parent,
va_start (ap, format);
text = g_strdup_vprintf (format, ap);
va_end (ap);
- self = g_object_new (NAUTILUS_TYPE_WIPE_PROGRESS_DIALOG,
+ self = g_object_new (NW_TYPE_PROGRESS_DIALOG,
"transient-for", parent,
#if ! GTK_CHECK_VERSION (3, 0, 0)
"has-separator", FALSE,
@@ -296,108 +296,108 @@ nautilus_wipe_progress_dialog_new (GtkWindow *parent,
"text", text,
NULL);
g_free (text);
- update_action_area_visibility (NAUTILUS_WIPE_PROGRESS_DIALOG (self), FALSE);
+ update_action_area_visibility (NW_PROGRESS_DIALOG (self), FALSE);
return self;
}
/**
- * nautilus_wipe_progress_dialog_set_fraction:
- * @dialog: A #NautilusWipeProgressDialog
+ * nw_progress_dialog_set_fraction:
+ * @dialog: A #NwProgressDialog
* @fraction: The current progression.
*
* See gtk_progress_bar_set_fraction().
*/
void
-nautilus_wipe_progress_dialog_set_fraction (NautilusWipeProgressDialog *dialog,
- gdouble fraction)
+nw_progress_dialog_set_fraction (NwProgressDialog *dialog,
+ gdouble fraction)
{
- g_return_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog));
+ g_return_if_fail (NW_IS_PROGRESS_DIALOG (dialog));
gtk_progress_bar_set_fraction (dialog->priv->progress, fraction);
}
/**
- * nautilus_wipe_progress_dialog_get_fraction:
- * @dialog: A #NautilusWipeProgressDialog
+ * nw_progress_dialog_get_fraction:
+ * @dialog: A #NwProgressDialog
*
* See gtk_progress_bar_get_fraction().
*
* Returns: The current progress of the dialog's progress bar.
*/
gdouble
-nautilus_wipe_progress_dialog_get_fraction (NautilusWipeProgressDialog *dialog)
+nw_progress_dialog_get_fraction (NwProgressDialog *dialog)
{
- g_return_val_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog), 0.0);
+ g_return_val_if_fail (NW_IS_PROGRESS_DIALOG (dialog), 0.0);
return gtk_progress_bar_get_fraction (dialog->priv->progress);
}
/**
- * nautilus_wipe_progress_dialog_pulse:
- * @dialog: A #NautilusWipeProgressDialog
+ * nw_progress_dialog_pulse:
+ * @dialog: A #NwProgressDialog
*
* See gtk_progress_bar_pulse().
*/
void
-nautilus_wipe_progress_dialog_pulse (NautilusWipeProgressDialog *dialog)
+nw_progress_dialog_pulse (NwProgressDialog *dialog)
{
- g_return_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog));
+ g_return_if_fail (NW_IS_PROGRESS_DIALOG (dialog));
gtk_progress_bar_pulse (dialog->priv->progress);
}
/**
- * nautilus_wipe_progress_dialog_set_pulse_step:
- * @dialog: A #NautilusWipeProgressDialog
+ * nw_progress_dialog_set_pulse_step:
+ * @dialog: A #NwProgressDialog
* @fraction: The pulse step of the dialog's progress bar.
*
* See gtk_progress_bar_set_pulse_step().
*/
void
-nautilus_wipe_progress_dialog_set_pulse_step (NautilusWipeProgressDialog *dialog,
- gdouble fraction)
+nw_progress_dialog_set_pulse_step (NwProgressDialog *dialog,
+ gdouble fraction)
{
- g_return_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog));
+ g_return_if_fail (NW_IS_PROGRESS_DIALOG (dialog));
gtk_progress_bar_set_pulse_step (dialog->priv->progress, fraction);
}
/**
- * nautilus_wipe_progress_dialog_get_pulse_step:
- * @dialog: A #NautilusWipeProgressDialog
+ * nw_progress_dialog_get_pulse_step:
+ * @dialog: A #NwProgressDialog
*
* See gtk_progress_bar_get_pulse_step().
*
* Returns: The progress step of the dialog's progress bar.
*/
gdouble
-nautilus_wipe_progress_dialog_get_pulse_step (NautilusWipeProgressDialog *dialog)
+nw_progress_dialog_get_pulse_step (NwProgressDialog *dialog)
{
- g_return_val_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog), 0.0);
+ g_return_val_if_fail (NW_IS_PROGRESS_DIALOG (dialog), 0.0);
return gtk_progress_bar_get_pulse_step (dialog->priv->progress);
}
/**
- * nautilus_wipe_progress_dialog_set_progress_text:
- * @dialog: A #NautilusWipeProgressDialog
+ * nw_progress_dialog_set_progress_text:
+ * @dialog: A #NwProgressDialog
* @format: Text format (printf-like)
* @...: Arguments for @format
*
* Sets the progress text. For details about @format and @..., see the
* documentation of g_strdup_printf().
- * Don't mistake this function for nautilus_wipe_progress_dialog_set_text().
+ * Don't mistake this function for nw_progress_dialog_set_text().
*/
void
-nautilus_wipe_progress_dialog_set_progress_text (NautilusWipeProgressDialog *dialog,
- const gchar *format,
- ...)
+nw_progress_dialog_set_progress_text (NwProgressDialog *dialog,
+ const gchar *format,
+ ...)
{
gchar *text;
va_list ap;
- g_return_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog));
+ g_return_if_fail (NW_IS_PROGRESS_DIALOG (dialog));
va_start (ap, format);
text = g_strdup_vprintf (format, ap);
@@ -407,43 +407,43 @@ nautilus_wipe_progress_dialog_set_progress_text (NautilusWipeProgressDialog *dia
}
/**
- * nautilus_wipe_progress_dialog_get_progress_text:
- * @dialog: A #NautilusWipeProgressDialog
+ * nw_progress_dialog_get_progress_text:
+ * @dialog: A #NwProgressDialog
*
* Gets the current progress text of @dialog. Don't mistake for
- * nautilus_wipe_progress_dialog_get_text().
+ * nw_progress_dialog_get_text().
*
* Returns: The progress text of the dialog.
*/
const gchar *
-nautilus_wipe_progress_dialog_get_progress_text (NautilusWipeProgressDialog *dialog)
+nw_progress_dialog_get_progress_text (NwProgressDialog *dialog)
{
- g_return_val_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog), NULL);
+ g_return_val_if_fail (NW_IS_PROGRESS_DIALOG (dialog), NULL);
return gtk_progress_bar_get_text (dialog->priv->progress);
}
/**
- * nautilus_wipe_progress_dialog_set_text:
- * @dialog: A #NautilusWipeProgressDialog
+ * nw_progress_dialog_set_text:
+ * @dialog: A #NwProgressDialog
* @format: Text format (printf-like)
* @...: Arguments for @format
*
* Sets the dialog's text. For details about @format and @..., see the
* documentation of g_strdup_printf().
* Don't mistake this function for
- * nautilus_wipe_progress_dialog_set_progress_text() that do the same but for the
+ * nw_progress_dialog_set_progress_text() that do the same but for the
* progress text instead of the dialog's main text.
*/
void
-nautilus_wipe_progress_dialog_set_text (NautilusWipeProgressDialog *dialog,
- const gchar *format,
- ...)
+nw_progress_dialog_set_text (NwProgressDialog *dialog,
+ const gchar *format,
+ ...)
{
gchar *text;
va_list ap;
- g_return_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog));
+ g_return_if_fail (NW_IS_PROGRESS_DIALOG (dialog));
va_start (ap, format);
text = g_strdup_vprintf (format, ap);
@@ -453,26 +453,26 @@ nautilus_wipe_progress_dialog_set_text (NautilusWipeProgressDialog *dialog,
}
/**
- * nautilus_wipe_progress_dialog_get_text:
- * @dialog: A #NautilusWipeProgressDialog
+ * nw_progress_dialog_get_text:
+ * @dialog: A #NwProgressDialog
*
* Gets the text message of the dialog. Don't mistake this function for
- * nautilus_wipe_progress_dialog_get_progress_text().
+ * nw_progress_dialog_get_progress_text().
*
* Returns: The text of @dialog.
*/
const gchar *
-nautilus_wipe_progress_dialog_get_text (NautilusWipeProgressDialog *dialog)
+nw_progress_dialog_get_text (NwProgressDialog *dialog)
{
- g_return_val_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog), NULL);
+ g_return_val_if_fail (NW_IS_PROGRESS_DIALOG (dialog), NULL);
return gtk_label_get_text (dialog->priv->label);
}
void
-nautilus_wipe_progress_dialog_cancel (NautilusWipeProgressDialog *dialog)
+nw_progress_dialog_cancel (NwProgressDialog *dialog)
{
- g_return_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog));
+ g_return_if_fail (NW_IS_PROGRESS_DIALOG (dialog));
if (! dialog->priv->canceled) {
dialog->priv->canceled = TRUE;
@@ -483,57 +483,57 @@ nautilus_wipe_progress_dialog_cancel (NautilusWipeProgressDialog *dialog)
}
gboolean
-nautilus_wipe_progress_dialog_is_canceled (NautilusWipeProgressDialog *dialog)
+nw_progress_dialog_is_canceled (NwProgressDialog *dialog)
{
- g_return_val_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog), FALSE);
+ g_return_val_if_fail (NW_IS_PROGRESS_DIALOG (dialog), FALSE);
return dialog->priv->canceled;
}
/**
- * nautilus_wipe_progress_dialog_finish:
- * @dialog: A #NautilusWipeProgressDialog
+ * nw_progress_dialog_finish:
+ * @dialog: A #NwProgressDialog
* @success: Whether the operation finished successfully or not
*
*
*/
void
-nautilus_wipe_progress_dialog_finish (NautilusWipeProgressDialog *dialog,
- gboolean success)
+nw_progress_dialog_finish (NwProgressDialog *dialog,
+ gboolean success)
{
- g_return_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog));
+ g_return_if_fail (NW_IS_PROGRESS_DIALOG (dialog));
dialog->priv->finished = TRUE;
if (success) {
/* ensure the progression is shown completed */
- nautilus_wipe_progress_dialog_set_fraction (dialog, 1.0);
+ nw_progress_dialog_set_fraction (dialog, 1.0);
}
gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL,
FALSE);
gtk_dialog_response (GTK_DIALOG (dialog),
- NAUTILUS_WIPE_PROGRESS_DIALOG_RESPONSE_COMPLETE);
+ NW_PROGRESS_DIALOG_RESPONSE_COMPLETE);
}
/**
- * nautilus_wipe_progress_dialog_is_finished:
- * @dialog: A #NautilusWipeProgressDialog
+ * nw_progress_dialog_is_finished:
+ * @dialog: A #NwProgressDialog
*
* Gets whether the operation that @dialog displays is finished or not.
- * This is set by nautilus_wipe_progress_dialog_finish().
+ * This is set by nw_progress_dialog_finish().
*
* Returns: Whether the operation displayed by @dialog is finished or not.
*/
gboolean
-nautilus_wipe_progress_dialog_is_finished (NautilusWipeProgressDialog *dialog)
+nw_progress_dialog_is_finished (NwProgressDialog *dialog)
{
- g_return_val_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog), FALSE);
+ g_return_val_if_fail (NW_IS_PROGRESS_DIALOG (dialog), FALSE);
return dialog->priv->finished;
}
/**
- * nautilus_wipe_progress_dialog_set_has_close_button:
- * @dialog: A #NautilusWipeProgressDialog
+ * nw_progress_dialog_set_has_close_button:
+ * @dialog: A #NwProgressDialog
* @has_close_button: Whether the dialog should have a close button.
*
* Sets whether the dialog has a close button. Enabling close button at the
@@ -542,10 +542,10 @@ nautilus_wipe_progress_dialog_is_finished (NautilusWipeProgressDialog *dialog)
* either finished or canceled).
*/
void
-nautilus_wipe_progress_dialog_set_has_close_button (NautilusWipeProgressDialog *dialog,
- gboolean has_close_button)
+nw_progress_dialog_set_has_close_button (NwProgressDialog *dialog,
+ gboolean has_close_button)
{
- g_return_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog));
+ g_return_if_fail (NW_IS_PROGRESS_DIALOG (dialog));
if (has_close_button != (dialog->priv->close_button != NULL)) {
if (has_close_button) {
@@ -563,22 +563,22 @@ nautilus_wipe_progress_dialog_set_has_close_button (NautilusWipeProgressDialog *
}
/**
- * nautilus_wipe_progress_dialog_get_has_close_button:
- * @dialog: A #NautilusWipeProgressDialog
+ * nw_progress_dialog_get_has_close_button:
+ * @dialog: A #NwProgressDialog
*
* Returns: Whether @dialog has a close button or not.
*/
gboolean
-nautilus_wipe_progress_dialog_get_has_close_button (NautilusWipeProgressDialog *dialog)
+nw_progress_dialog_get_has_close_button (NwProgressDialog *dialog)
{
- g_return_val_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog), FALSE);
+ g_return_val_if_fail (NW_IS_PROGRESS_DIALOG (dialog), FALSE);
return dialog->priv->close_button != NULL;
}
/**
- * nautilus_wipe_progress_dialog_set_has_cancel_button:
- * @dialog: A #NautilusWipeProgressDialog
+ * nw_progress_dialog_set_has_cancel_button:
+ * @dialog: A #NwProgressDialog
* @has_cancel_button: Whether the dialog should have a cancel button.
*
* Sets whether the dialog has a cancel button. Enabling cancel button at the
@@ -587,10 +587,10 @@ nautilus_wipe_progress_dialog_get_has_close_button (NautilusWipeProgressDialog *
* neither finished nor canceled).
*/
void
-nautilus_wipe_progress_dialog_set_has_cancel_button (NautilusWipeProgressDialog *dialog,
- gboolean has_cancel_button)
+nw_progress_dialog_set_has_cancel_button (NwProgressDialog *dialog,
+ gboolean has_cancel_button)
{
- g_return_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog));
+ g_return_if_fail (NW_IS_PROGRESS_DIALOG (dialog));
if (has_cancel_button != (dialog->priv->cancel_button != NULL)) {
if (has_cancel_button) {
@@ -608,24 +608,24 @@ nautilus_wipe_progress_dialog_set_has_cancel_button (NautilusWipeProgressDialog
}
/**
- * nautilus_wipe_progress_dialog_get_has_cancel_button:
- * @dialog: A #NautilusWipeProgressDialog
+ * nw_progress_dialog_get_has_cancel_button:
+ * @dialog: A #NwProgressDialog
*
* Returns: Whether @dialog has a cancel button.
*/
gboolean
-nautilus_wipe_progress_dialog_get_has_cancel_button (NautilusWipeProgressDialog *dialog)
+nw_progress_dialog_get_has_cancel_button (NwProgressDialog *dialog)
{
- g_return_val_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog), FALSE);
+ g_return_val_if_fail (NW_IS_PROGRESS_DIALOG (dialog), FALSE);
return dialog->priv->cancel_button != NULL;
}
void
-nautilus_wipe_progress_dialog_set_auto_hide_action_area (NautilusWipeProgressDialog *dialog,
- gboolean auto_hide)
+nw_progress_dialog_set_auto_hide_action_area (NwProgressDialog *dialog,
+ gboolean auto_hide)
{
- g_return_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog));
+ g_return_if_fail (NW_IS_PROGRESS_DIALOG (dialog));
if (auto_hide != dialog->priv->auto_hide_action_area) {
dialog->priv->auto_hide_action_area = auto_hide;
@@ -634,9 +634,9 @@ nautilus_wipe_progress_dialog_set_auto_hide_action_area (NautilusWipeProgressDia
}
gboolean
-nautilus_wipe_progress_dialog_get_auto_hide_action_area (NautilusWipeProgressDialog *dialog)
+nw_progress_dialog_get_auto_hide_action_area (NwProgressDialog *dialog)
{
- g_return_val_if_fail (NAUTILUS_IS_WIPE_PROGRESS_DIALOG (dialog), FALSE);
+ g_return_val_if_fail (NW_IS_PROGRESS_DIALOG (dialog), FALSE);
return dialog->priv->auto_hide_action_area;
}
diff --git a/nautilus-wipe/nw-progress-dialog.h b/nautilus-wipe/nw-progress-dialog.h
new file mode 100644
index 0000000..f65b287
--- /dev/null
+++ b/nautilus-wipe/nw-progress-dialog.h
@@ -0,0 +1,96 @@
+/*
+ * nautilus-wipe - a nautilus extension to wipe file(s)
+ *
+ * Copyright (C) 2009-2011 Colomban Wendling <ban at herbesfolles.org>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public
+ * License as published by the Free Software Foundation; either
+ * version 3 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public
+ * License along with this library; if not, write to the Free
+ * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ */
+
+#ifndef NW_PROGRESS_DIALOG_H
+#define NW_PROGRESS_DIALOG_H
+
+#include <stdarg.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+
+
+G_BEGIN_DECLS
+
+
+#define NW_TYPE_PROGRESS_DIALOG (nw_progress_dialog_get_type ())
+#define NW_PROGRESS_DIALOG(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), NW_TYPE_PROGRESS_DIALOG, NwProgressDialog))
+#define NW_PROGRESS_DIALOG_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), NW_TYPE_PROGRESS_DIALOG, NwProgressDialogClass))
+#define NW_IS_PROGRESS_DIALOG(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), NW_TYPE_PROGRESS_DIALOG))
+#define NW_IS_PROGRESS_DIALOG_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), NW_TYPE_PROGRESS_DIALOG))
+#define NW_PROGRESS_DIALOG_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), NW_TYPE_PROGRESS_DIALOG, NwProgressDialogClass))
+
+typedef struct _NwProgressDialog NwProgressDialog;
+typedef struct _NwProgressDialogClass NwProgressDialogClass;
+typedef struct _NwProgressDialogPrivate NwProgressDialogPrivate;
+
+struct _NwProgressDialog {
+ GtkDialog parent_instance;
+ NwProgressDialogPrivate *priv;
+};
+
+struct _NwProgressDialogClass {
+ GtkDialogClass parent_class;
+};
+
+#define NW_PROGRESS_DIALOG_RESPONSE_COMPLETE 1
+
+
+GType nw_progress_dialog_get_type (void) G_GNUC_CONST;
+
+GtkWidget *nw_progress_dialog_new (GtkWindow *parent,
+ GtkDialogFlags flags,
+ const gchar *format,
+ ...);
+void nw_progress_dialog_set_fraction (NwProgressDialog *dialog,
+ gdouble fraction);
+gdouble nw_progress_dialog_get_fraction (NwProgressDialog *dialog);
+void nw_progress_dialog_pulse (NwProgressDialog *dialog);
+void nw_progress_dialog_set_pulse_step (NwProgressDialog *dialog,
+ gdouble fraction);
+gdouble nw_progress_dialog_get_pulse_step (NwProgressDialog *dialog);
+void nw_progress_dialog_set_progress_text (NwProgressDialog *dialog,
+ const gchar *format,
+ ...);
+const gchar *nw_progress_dialog_get_progress_text (NwProgressDialog *dialog);
+void nw_progress_dialog_set_text (NwProgressDialog *dialog,
+ const gchar *format,
+ ...);
+const gchar *nw_progress_dialog_get_text (NwProgressDialog *dialog);
+void nw_progress_dialog_cancel (NwProgressDialog *dialog);
+gboolean nw_progress_dialog_is_canceled (NwProgressDialog *dialog);
+void nw_progress_dialog_finish (NwProgressDialog *dialog,
+ gboolean success);
+gboolean nw_progress_dialog_is_finished (NwProgressDialog *dialog);
+void nw_progress_dialog_set_has_close_button (NwProgressDialog *dialog,
+ gboolean has_close_button);
+gboolean nw_progress_dialog_get_has_close_button (NwProgressDialog *dialog);
+void nw_progress_dialog_set_has_cancel_button (NwProgressDialog *dialog,
+ gboolean has_close_button);
+gboolean nw_progress_dialog_get_has_cancel_button (NwProgressDialog *dialog);
+
+void nw_progress_dialog_set_auto_hide_action_area (NwProgressDialog *dialog,
+ gboolean auto_hide);
+gboolean nw_progress_dialog_get_auto_hide_action_area (NwProgressDialog *dialog);
+
+
+G_END_DECLS
+
+#endif /* guard */
diff --git a/nautilus-wipe/type-utils.h b/nautilus-wipe/nw-type-utils.h
similarity index 86%
rename from nautilus-wipe/type-utils.h
rename to nautilus-wipe/nw-type-utils.h
index 6da1250..5faa02d 100644
--- a/nautilus-wipe/type-utils.h
+++ b/nautilus-wipe/nw-type-utils.h
@@ -19,8 +19,8 @@
*
*/
-#ifndef NAUTILUS_WIPE_TYPE_UTILS_H
-#define NAUTILUS_WIPE_TYPE_UTILS_H
+#ifndef NW_TYPE_UTILS_H
+#define NW_TYPE_UTILS_H
#include <glib.h>
#include <glib-object.h>
@@ -28,7 +28,7 @@
G_BEGIN_DECLS
-#define _NAUTILUS_WIPE_DEFINE_TYPE_MODULE_EXTENDED_BEGIN(TN, t_n, T_P, _f_) \
+#define _NW_DEFINE_TYPE_MODULE_EXTENDED_BEGIN(TN, t_n, T_P, _f_) \
\
static void t_n##_init (TN *self); \
static void t_n##_class_init (TN##Class *klass); \
@@ -73,26 +73,26 @@ t_n##_register_type (GTypeModule *nw_define_type_module_module) \
&type_info, _f_); \
t_n##__GType = nw_define_type_module_id; \
{ /* custom code follows */
-#define _NAUTILUS_WIPE_DEFINE_TYPE_MODULE_EXTENDED_END() \
+#define _NW_DEFINE_TYPE_MODULE_EXTENDED_END() \
/* following custom code */ \
} \
return nw_define_type_module_id; \
}
-#define NAUTILUS_WIPE_DEFINE_TYPE_MODULE_EXTENDED(TN, t_n, T_P, _f_, _C_) \
- _NAUTILUS_WIPE_DEFINE_TYPE_MODULE_EXTENDED_BEGIN (TN, t_n, T_P, _f_) \
+#define NW_DEFINE_TYPE_MODULE_EXTENDED(TN, t_n, T_P, _f_, _C_) \
+ _NW_DEFINE_TYPE_MODULE_EXTENDED_BEGIN (TN, t_n, T_P, _f_) \
{ _C_; } \
- _NAUTILUS_WIPE_DEFINE_TYPE_MODULE_EXTENDED_END ()
+ _NW_DEFINE_TYPE_MODULE_EXTENDED_END ()
-#define NAUTILUS_WIPE_DEFINE_TYPE_MODULE_WITH_CODE(TN, t_n, T_P, _C_) \
- _NAUTILUS_WIPE_DEFINE_TYPE_MODULE_EXTENDED_BEGIN (TN, t_n, T_P, 0) \
+#define NW_DEFINE_TYPE_MODULE_WITH_CODE(TN, t_n, T_P, _C_) \
+ _NW_DEFINE_TYPE_MODULE_EXTENDED_BEGIN (TN, t_n, T_P, 0) \
{ _C_; } \
- _NAUTILUS_WIPE_DEFINE_TYPE_MODULE_EXTENDED_END ()
+ _NW_DEFINE_TYPE_MODULE_EXTENDED_END ()
-#define NAUTILUS_WIPE_DEFINE_TYPE_MODULE(TN, t_n, T_P) \
- NAUTILUS_WIPE_DEFINE_TYPE_MODULE_EXTENDED (TN, t_n, T_P, 0, {})
+#define NW_DEFINE_TYPE_MODULE(TN, t_n, T_P) \
+ NW_DEFINE_TYPE_MODULE_EXTENDED (TN, t_n, T_P, 0, {})
-#define NAUTILUS_WIPE_TYPE_MODULE_IMPLEMENT_INTERFACE(TYPE_IFACE, iface_init) \
+#define NW_TYPE_MODULE_IMPLEMENT_INTERFACE(TYPE_IFACE, iface_init) \
{ \
static const GInterfaceInfo nw_type_module_implement_interface_info = { \
(GInterfaceInitFunc) iface_init, NULL, NULL \
diff --git a/nautilus-wipe/operation-manager.h b/nautilus-wipe/operation-manager.h
deleted file mode 100644
index 9374656..0000000
--- a/nautilus-wipe/operation-manager.h
+++ /dev/null
@@ -1,73 +0,0 @@
-/*
- * nautilus-wipe - a nautilus extension to wipe file(s)
- *
- * Copyright (C) 2009-2011 Colomban Wendling <ban at herbesfolles.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- */
-
-#ifndef NAUTILUS_WIPE_OPERATION_MANAGER_H
-#define NAUTILUS_WIPE_OPERATION_MANAGER_H
-
-#include <glib.h>
-#include <glib-object.h>
-#include <gtk/gtk.h>
-#include <gsecuredelete/gsecuredelete.h>
-
-G_BEGIN_DECLS
-
-
-/**
- * NautilusWipeOperationFunc:
- * @files: Paths to work on
- * @fast: The Gsd.SecureDeleteOperation:fast setting
- * @mode: The Gsd.SecureDeleteOperation:mode setting
- * @zeroise: The Gsd.ZeroableOperation:zeroise setting
- * @finished_handler: Handler for GsdAsyncOperation::finished
- * @progress_handler: Handler for GsdAsyncOperation::progress
- * @data: User data for @finished_hanlder and @progress_handler
- * @error: Return location for errors, or %NULL to ignore them
- *
- *
- * Returns: The operation object that was launched, or %NULL on failure.
- * The operation object should be unref'd with g_object_unref() when
- * no longer needed.
- */
-typedef GsdAsyncOperation *(*NautilusWipeOperationFunc) (GList *files,
- gboolean fast,
- GsdSecureDeleteOperationMode mode,
- gboolean zeroise,
- GCallback finished_handler,
- GCallback progress_handler,
- gpointer data,
- GError **error);
-
-void nautilus_wipe_operation_manager_run (GtkWindow *parent,
- GList *files,
- const gchar *confirm_primary_text,
- const gchar *confirm_secondary_text,
- const gchar *confirm_button_text,
- GtkWidget *confirm_button_icon,
- const gchar *progress_dialog_text,
- NautilusWipeOperationFunc operation_launcher_func,
- const gchar *failed_primary_text,
- const gchar *success_primary_text,
- const gchar *success_secondary_text);
-
-
-G_END_DECLS
-
-#endif /* guard */
diff --git a/nautilus-wipe/progress-dialog.h b/nautilus-wipe/progress-dialog.h
deleted file mode 100644
index d34e57a..0000000
--- a/nautilus-wipe/progress-dialog.h
+++ /dev/null
@@ -1,96 +0,0 @@
-/*
- * nautilus-wipe - a nautilus extension to wipe file(s)
- *
- * Copyright (C) 2009-2011 Colomban Wendling <ban at herbesfolles.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- */
-
-#ifndef NAUTILUS_WIPE_PROGRESS_DIALOG_H
-#define NAUTILUS_WIPE_PROGRESS_DIALOG_H
-
-#include <stdarg.h>
-#include <glib.h>
-#include <gtk/gtk.h>
-
-
-G_BEGIN_DECLS
-
-
-#define NAUTILUS_TYPE_WIPE_PROGRESS_DIALOG (nautilus_wipe_progress_dialog_get_type ())
-#define NAUTILUS_WIPE_PROGRESS_DIALOG(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), NAUTILUS_TYPE_WIPE_PROGRESS_DIALOG, NautilusWipeProgressDialog))
-#define NAUTILUS_WIPE_PROGRESS_DIALOG_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), NAUTILUS_TYPE_WIPE_PROGRESS_DIALOG, NautilusWipeProgressDialogClass))
-#define NAUTILUS_IS_WIPE_PROGRESS_DIALOG(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), NAUTILUS_TYPE_WIPE_PROGRESS_DIALOG))
-#define NAUTILUS_IS_WIPE_PROGRESS_DIALOG_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), NAUTILUS_TYPE_WIPE_PROGRESS_DIALOG))
-#define NAUTILUS_WIPE_PROGRESS_DIALOG_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), NAUTILUS_TYPE_WIPE_PROGRESS_DIALOG, NautilusWipeProgressDialogClass))
-
-typedef struct _NautilusWipeProgressDialog NautilusWipeProgressDialog;
-typedef struct _NautilusWipeProgressDialogClass NautilusWipeProgressDialogClass;
-typedef struct _NautilusWipeProgressDialogPrivate NautilusWipeProgressDialogPrivate;
-
-struct _NautilusWipeProgressDialog {
- GtkDialog parent_instance;
- NautilusWipeProgressDialogPrivate *priv;
-};
-
-struct _NautilusWipeProgressDialogClass {
- GtkDialogClass parent_class;
-};
-
-#define NAUTILUS_WIPE_PROGRESS_DIALOG_RESPONSE_COMPLETE 1
-
-
-GType nautilus_wipe_progress_dialog_get_type (void) G_GNUC_CONST;
-
-GtkWidget *nautilus_wipe_progress_dialog_new (GtkWindow *parent,
- GtkDialogFlags flags,
- const gchar *format,
- ...);
-void nautilus_wipe_progress_dialog_set_fraction (NautilusWipeProgressDialog *dialog,
- gdouble fraction);
-gdouble nautilus_wipe_progress_dialog_get_fraction (NautilusWipeProgressDialog *dialog);
-void nautilus_wipe_progress_dialog_pulse (NautilusWipeProgressDialog *dialog);
-void nautilus_wipe_progress_dialog_set_pulse_step (NautilusWipeProgressDialog *dialog,
- gdouble fraction);
-gdouble nautilus_wipe_progress_dialog_get_pulse_step (NautilusWipeProgressDialog *dialog);
-void nautilus_wipe_progress_dialog_set_progress_text (NautilusWipeProgressDialog *dialog,
- const gchar *format,
- ...);
-const gchar *nautilus_wipe_progress_dialog_get_progress_text (NautilusWipeProgressDialog *dialog);
-void nautilus_wipe_progress_dialog_set_text (NautilusWipeProgressDialog *dialog,
- const gchar *format,
- ...);
-const gchar *nautilus_wipe_progress_dialog_get_text (NautilusWipeProgressDialog *dialog);
-void nautilus_wipe_progress_dialog_cancel (NautilusWipeProgressDialog *dialog);
-gboolean nautilus_wipe_progress_dialog_is_canceled (NautilusWipeProgressDialog *dialog);
-void nautilus_wipe_progress_dialog_finish (NautilusWipeProgressDialog *dialog,
- gboolean success);
-gboolean nautilus_wipe_progress_dialog_is_finished (NautilusWipeProgressDialog *dialog);
-void nautilus_wipe_progress_dialog_set_has_close_button (NautilusWipeProgressDialog *dialog,
- gboolean has_close_button);
-gboolean nautilus_wipe_progress_dialog_get_has_close_button (NautilusWipeProgressDialog *dialog);
-void nautilus_wipe_progress_dialog_set_has_cancel_button (NautilusWipeProgressDialog *dialog,
- gboolean has_close_button);
-gboolean nautilus_wipe_progress_dialog_get_has_cancel_button (NautilusWipeProgressDialog *dialog);
-
-void nautilus_wipe_progress_dialog_set_auto_hide_action_area (NautilusWipeProgressDialog *dialog,
- gboolean auto_hide);
-gboolean nautilus_wipe_progress_dialog_get_auto_hide_action_area (NautilusWipeProgressDialog *dialog);
-
-
-G_END_DECLS
-
-#endif /* guard */
diff --git a/po/POTFILES.in b/po/POTFILES.in
index dd396f6..58a77a4 100644
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -1,5 +1,5 @@
# List of source files which contain translatable strings.
-nautilus-wipe/delete-operation.c
-nautilus-wipe/fill-operation.c
-nautilus-wipe/nautilus-wipe.c
-nautilus-wipe/operation-manager.c
+nautilus-wipe/nw-delete-operation.c
+nautilus-wipe/nw-fill-operation.c
+nautilus-wipe/nw-extension.c
+nautilus-wipe/nw-operation-manager.c
diff --git a/nautilus-wipe/fill-operation.c b/nautilus-wipe/nw-fill-operation.c
similarity index 77%
rename from nautilus-wipe/fill-operation.c
rename to nautilus-wipe/nw-fill-operation.c
index 68d8c7b..9ab26e3 100644
--- a/nautilus-wipe/fill-operation.c
+++ b/nautilus-wipe/nw-fill-operation.c
@@ -23,7 +23,7 @@
# include "config.h"
#endif
-#include "fill-operation.h"
+#include "nw-fill-operation.h"
#include <glib.h>
#include <glib/gi18n-lib.h>
@@ -33,16 +33,16 @@
# include <gio/gunixmounts.h>
#endif
#include <gsecuredelete/gsecuredelete.h>
-#include "path-list.h"
+#include "nw-path-list.h"
GQuark
-nautilus_wipe_fill_operation_error_quark (void)
+nw_fill_operation_error_quark (void)
{
static volatile gsize quark = 0;
if (g_once_init_enter (&quark)) {
- GQuark q = g_quark_from_static_string ("NautilusWipeFillOperationError");
+ GQuark q = g_quark_from_static_string ("NwFillOperationError");
g_once_init_leave (&quark, q);
}
@@ -116,8 +116,8 @@ find_mountpoint (const gchar *path,
gchar *uri = g_file_get_uri (mountpoint_file);
g_set_error (&err,
- NAUTILUS_WIPE_FILL_OPERATION_ERROR,
- NAUTILUS_WIPE_FILL_OPERATION_ERROR_REMOTE_MOUNT,
+ NW_FILL_OPERATION_ERROR,
+ NW_FILL_OPERATION_ERROR_REMOTE_MOUNT,
_("Mount \"%s\" is not local"), uri);
g_free (uri);
}
@@ -132,8 +132,8 @@ find_mountpoint (const gchar *path,
mountpoint_path = find_mountpoint_unix (path);
if (! mountpoint_path) {
g_set_error (&err,
- NAUTILUS_WIPE_FILL_OPERATION_ERROR,
- NAUTILUS_WIPE_FILL_OPERATION_ERROR_MISSING_MOUNT,
+ NW_FILL_OPERATION_ERROR,
+ NW_FILL_OPERATION_ERROR_MISSING_MOUNT,
_("No mount point found for path \"%s\""), path);
}
}
@@ -174,13 +174,13 @@ struct FillOperationData
gpointer cbdata;
};
-static void nautilus_wipe_fill_finished_handler (GsdFillOperation *operation,
- gboolean success,
- const gchar *message,
- struct FillOperationData *opdata);
-static void nautilus_wipe_fill_progress_handler (GsdFillOperation *operation,
- gdouble fraction,
- struct FillOperationData *opdata);
+static void nw_fill_finished_handler (GsdFillOperation *operation,
+ gboolean success,
+ const gchar *message,
+ struct FillOperationData *opdata);
+static void nw_fill_progress_handler (GsdFillOperation *operation,
+ gdouble fraction,
+ struct FillOperationData *opdata);
/* Actually calls libgsecuredelete */
@@ -196,7 +196,7 @@ do_fill_operation (struct FillOperationData *opdata,
/* Removes the current directory to proceed */
static void
-nautilus_wipe_fill_pop_dir (struct FillOperationData *opdata)
+nw_fill_pop_dir (struct FillOperationData *opdata)
{
GList *tmp;
@@ -208,7 +208,7 @@ nautilus_wipe_fill_pop_dir (struct FillOperationData *opdata)
/* Cleans up the opdata structure and frees it */
static void
-nautilus_wipe_fill_cleanup (struct FillOperationData *opdata)
+nw_fill_cleanup (struct FillOperationData *opdata)
{
g_signal_handler_disconnect (opdata->operation, opdata->progress_hid);
g_signal_handler_disconnect (opdata->operation, opdata->finished_hid);
@@ -216,7 +216,7 @@ nautilus_wipe_fill_cleanup (struct FillOperationData *opdata)
g_object_unref (opdata->operation);
}
while (opdata->dir) {
- nautilus_wipe_fill_pop_dir (opdata);
+ nw_fill_pop_dir (opdata);
}
g_slice_free1 (sizeof *opdata, opdata);
}
@@ -224,9 +224,9 @@ nautilus_wipe_fill_cleanup (struct FillOperationData *opdata)
/* wrapper for the progress handler returning the current progression over all
* operations */
static void
-nautilus_wipe_fill_progress_handler (GsdFillOperation *operation,
- gdouble fraction,
- struct FillOperationData *opdata)
+nw_fill_progress_handler (GsdFillOperation *operation,
+ gdouble fraction,
+ struct FillOperationData *opdata)
{
opdata->progress_handler (operation,
(opdata->n_op_done + fraction) / opdata->n_op,
@@ -248,7 +248,7 @@ launch_next_fill_operation (struct FillOperationData *opdata)
success = do_fill_operation (opdata, &err);
if (! success) {
- nautilus_wipe_fill_finished_handler (opdata->operation,
+ nw_fill_finished_handler (opdata->operation,
success, err->message, opdata);
g_error_free (err);
}
@@ -261,14 +261,14 @@ launch_next_fill_operation (struct FillOperationData *opdata)
* It launches the next operation if there is one left, or call the user's
* handler if done or on error. */
static void
-nautilus_wipe_fill_finished_handler (GsdFillOperation *operation,
- gboolean success,
- const gchar *message,
- struct FillOperationData *opdata)
+nw_fill_finished_handler (GsdFillOperation *operation,
+ gboolean success,
+ const gchar *message,
+ struct FillOperationData *opdata)
{
opdata->n_op_done++;
/* remove the directory just proceeded */
- nautilus_wipe_fill_pop_dir (opdata);
+ nw_fill_pop_dir (opdata);
/* if the last operation succeeded and we have work left */
if (success && opdata->dir) {
/* we can't launch the next operation right here since the previous must
@@ -280,12 +280,12 @@ nautilus_wipe_fill_finished_handler (GsdFillOperation *operation,
g_timeout_add (10, (GSourceFunc)launch_next_fill_operation, opdata);
} else {
opdata->finished_handler (operation, success, message, opdata->cbdata);
- nautilus_wipe_fill_cleanup (opdata);
+ nw_fill_cleanup (opdata);
}
}
/*
- * nautilus_wipe_fill_operation_filter_files:
+ * nw_fill_operation_filter_files:
* @paths: A list of paths to filter
* @work_paths_: return location for filtered paths
* @work_mounts_: return location for filtered paths' mounts
@@ -297,15 +297,15 @@ nautilus_wipe_fill_finished_handler (GsdFillOperation *operation,
* The returned lists (@work_paths_ and @work_mounts_) have the same length, and
* an index in a list correspond to the same in the other:
* g_list_index(work_paths_, 0) is the path of g_list_index(work_mounts_, 0).
* Free returned lists with nautilus_wipe_path_list_free().
*
* Returns: %TRUE on success, %FALSE otherwise.
*/
gboolean
-nautilus_wipe_fill_operation_filter_files (GList *paths,
- GList **work_paths_,
- GList **work_mounts_,
- GError **error)
+nw_fill_operation_filter_files (GList *paths,
+ GList **work_paths_,
+ GList **work_mounts_,
+ GError **error)
{
GList *work_paths = NULL;
GError *err = NULL;
@@ -340,12 +340,12 @@ nautilus_wipe_fill_operation_filter_files (GList *paths,
}
}
if (err || ! work_paths_) {
- nautilus_wipe_path_list_free (work_paths);
+ nw_path_list_free (work_paths);
} else {
*work_paths_ = g_list_reverse (work_paths);
}
if (err || ! work_mounts_) {
- nautilus_wipe_path_list_free (work_mounts);
+ nw_path_list_free (work_mounts);
} else {
*work_mounts_ = g_list_reverse (work_mounts);
}
@@ -357,9 +357,9 @@ nautilus_wipe_fill_operation_filter_files (GList *paths,
}
/*
- * nautilus_wipe_fill_operation:
+ * nw_fill_operation:
* @directories: A list of paths to work on (should have been filtered with
- * nautilus_wipe_fill_operation_filter_files() or so)
+ * nw_fill_operation_filter_files() or so)
* @fast: The Gsd.SecureDeleteOperation:fast setting
* @mode: The Gsd.SecureDeleteOperation:mode setting
* @zeroise: The Gsd.ZeroableOperation:zeroise setting
@@ -376,14 +376,14 @@ nautilus_wipe_fill_operation_filter_files (GList *paths,
* no longer needed.
*/
GsdAsyncOperation *
-nautilus_wipe_fill_operation (GList *directories,
- gboolean fast,
- GsdSecureDeleteOperationMode mode,
- gboolean zeroise,
- GCallback finished_handler,
- GCallback progress_handler,
- gpointer data,
- GError **error)
+nw_fill_operation (GList *directories,
+ gboolean fast,
+ GsdSecureDeleteOperationMode mode,
+ gboolean zeroise,
+ GCallback finished_handler,
+ GCallback progress_handler,
+ gpointer data,
+ GError **error)
{
gboolean success = FALSE;
struct FillOperationData *opdata;
@@ -391,7 +391,7 @@ nautilus_wipe_fill_operation (GList *directories,
g_return_val_if_fail (directories != NULL, NULL);
- dirs = nautilus_wipe_path_list_copy (directories);
+ dirs = nw_path_list_copy (directories);
if (dirs) {
opdata = g_slice_alloc (sizeof *opdata);
opdata->dir = dirs;
@@ -405,13 +405,13 @@ nautilus_wipe_fill_operation (GList *directories,
gsd_secure_delete_operation_set_mode (GSD_SECURE_DELETE_OPERATION (opdata->operation), mode);
gsd_zeroable_operation_set_zeroise (GSD_ZEROABLE_OPERATION (opdata->operation), zeroise);
opdata->progress_hid = g_signal_connect (opdata->operation, "progress",
- G_CALLBACK (nautilus_wipe_fill_progress_handler), opdata);
+ G_CALLBACK (nw_fill_progress_handler), opdata);
opdata->finished_hid = g_signal_connect (opdata->operation, "finished",
- G_CALLBACK (nautilus_wipe_fill_finished_handler), opdata);
+ G_CALLBACK (nw_fill_finished_handler), opdata);
/* launches the operation */
success = do_fill_operation (opdata, error);
if (! success) {
- nautilus_wipe_fill_cleanup (opdata);
+ nw_fill_cleanup (opdata);
}
}
@@ -297,15 +297,15 @@ nautilus_wipe_fill_finished_handler (GsdFillOperation *operation,
* an index in a list correspond to the same in the other:
* g_list_index(work_paths_, 0) is the path of g_list_index(work_mounts_, 0).
- * Free returned lists with nautilus_wipe_path_list_free().
+ * Free returned lists with nw_path_list_free().
*
* Returns: %TRUE on success, %FALSE otherwise.
diff --git a/nautilus-wipe/operation-manager.c b/nautilus-wipe/nw-operation-manager.c
similarity index 89%
rename from nautilus-wipe/operation-manager.c
rename to nautilus-wipe/nw-operation-manager.c
index 3281e04..73ff48a 100644
--- a/nautilus-wipe/operation-manager.c
+++ b/nautilus-wipe/nw-operation-manager.c
@@ -23,7 +23,7 @@
# include "config.h"
#endif
-#include "operation-manager.h"
+#include "nw-operation-manager.h"
#include <stdarg.h>
#include <glib.h>
@@ -32,9 +32,8 @@
#include <gtk/gtk.h>
#include <gsecuredelete/gsecuredelete.h>
-#include "nautilus-wipe.h"
-#include "progress-dialog.h"
-#include "compat.h"
+#include "nw-progress-dialog.h"
+#include "nw-compat.h"
static GtkResponseType display_dialog (GtkWindow *parent,
@@ -139,20 +138,20 @@ string_last_line (const gchar *str)
-struct NautilusWipeOperationData
+struct NwOperationData
{
- GsdAsyncOperation *operation;
- GtkWindow *window;
- gulong window_destroy_hid;
- NautilusWipeProgressDialog *progress_dialog;
- gchar *failed_primary_text;
- gchar *success_primary_text;
- gchar *success_secondary_text;
+ GsdAsyncOperation *operation;
+ GtkWindow *window;
+ gulong window_destroy_hid;
+ NwProgressDialog *progress_dialog;
+ gchar *failed_primary_text;
+ gchar *success_primary_text;
+ gchar *success_secondary_text;
};
/* Frees a NautilusWipeOperationData structure */
static void
-free_opdata (struct NautilusWipeOperationData *opdata)
+free_opdata (struct NwOperationData *opdata)
{
if (opdata->window_destroy_hid) {
g_signal_handler_disconnect (opdata->window, opdata->window_destroy_hid);
@@ -169,8 +168,8 @@ free_opdata (struct NautilusWipeOperationData *opdata)
/* if the parent window get destroyed, we honor gently the thing and leave it
* to the death. doing this is useful not to have a bad window pointer later */
static void
-opdata_window_destroy_handler (GtkWidget *obj,
- struct NautilusWipeOperationData *opdata)
+opdata_window_destroy_handler (GtkWidget *obj,
+ struct NwOperationData *opdata)
{
g_signal_handler_disconnect (opdata->window, opdata->window_destroy_hid);
opdata->window_destroy_hid = 0;
@@ -179,8 +178,8 @@ opdata_window_destroy_handler (GtkWidget *obj,
/* Displays an operation's error */
static void
-display_operation_error (struct NautilusWipeOperationData *opdata,
- const gchar *error)
+display_operation_error (struct NwOperationData *opdata,
+ const gchar *error)
{
GtkWidget *dialog;
GtkWidget *content_area;
@@ -228,7 +227,7 @@ operation_finished_handler (GsdDeleteOperation *operation,
const gchar *error,
gpointer data)
{
- struct NautilusWipeOperationData *opdata = data;
+ struct NwOperationData *opdata = data;
gtk_widget_destroy (GTK_WIDGET (opdata->progress_dialog));
if (! success) {
@@ -248,10 +247,9 @@ operation_progress_handler (GsdDeleteOperation *operation,
gdouble fraction,
gpointer data)
{
- struct NautilusWipeOperationData *opdata = data;
+ struct NwOperationData *opdata = data;
- nautilus_wipe_progress_dialog_set_fraction (opdata->progress_dialog,
- fraction);
+ nw_progress_dialog_set_fraction (opdata->progress_dialog, fraction);
}
/* sets @pref according to state of @toggle */
@@ -464,7 +462,7 @@ progress_dialog_response_handler (GtkDialog *dialog,
gint response_id,
gpointer data)
{
- struct NautilusWipeOperationData *opdata = data;
+ struct NwOperationData *opdata = data;
switch (response_id) {
case GTK_RESPONSE_CANCEL:
@@ -486,7 +484,7 @@ progress_dialog_response_handler (GtkDialog *dialog,
}
/*
- * nautilus_wipe_operation_manager_run:
+ * nw_operation_manager_run:
* @parent: Parent window for dialogs
* @files: List of paths to pass to @operation_launcher_func
* @confirm_primary_text: Primary text for the confirmation dialog
@@ -506,17 +504,17 @@ progress_dialog_response_handler (GtkDialog *dialog,
*
*/
void
-nautilus_wipe_operation_manager_run (GtkWindow *parent,
- GList *files,
- const gchar *confirm_primary_text,
- const gchar *confirm_secondary_text,
- const gchar *confirm_button_text,
- GtkWidget *confirm_button_icon,
- const gchar *progress_dialog_text,
- NautilusWipeOperationFunc operation_launcher_func,
- const gchar *failed_primary_text,
- const gchar *success_primary_text,
- const gchar *success_secondary_text)
+nw_operation_manager_run (GtkWindow *parent,
+ GList *files,
+ const gchar *confirm_primary_text,
+ const gchar *confirm_secondary_text,
+ const gchar *confirm_button_text,
+ GtkWidget *confirm_button_icon,
+ const gchar *progress_dialog_text,
+ NwOperationFunc operation_launcher_func,
+ const gchar *failed_primary_text,
+ const gchar *success_primary_text,
+ const gchar *success_secondary_text)
{
/* if the user confirms, try to launch the operation */
gboolean fast = FALSE;
@@ -528,15 +526,15 @@ nautilus_wipe_operation_manager_run (GtkWindow *parent,
confirm_button_text, confirm_button_icon,
&fast, &delete_mode, &zeroise)) {
GError *err = NULL;
- struct NautilusWipeOperationData *opdata;
+ struct NwOperationData *opdata;
opdata = g_slice_alloc (sizeof *opdata);
opdata->window = parent;
opdata->window_destroy_hid = g_signal_connect (opdata->window, "destroy",
G_CALLBACK (opdata_window_destroy_handler), opdata);
- opdata->progress_dialog = NAUTILUS_WIPE_PROGRESS_DIALOG (nautilus_wipe_progress_dialog_new (opdata->window, 0,
- progress_dialog_text));
- nautilus_wipe_progress_dialog_set_has_cancel_button (opdata->progress_dialog, TRUE);
+ opdata->progress_dialog = NW_PROGRESS_DIALOG (nw_progress_dialog_new (opdata->window, 0,
+ progress_dialog_text));
+ nw_progress_dialog_set_has_cancel_button (opdata->progress_dialog, TRUE);
g_signal_connect (opdata->progress_dialog, "response",
G_CALLBACK (progress_dialog_response_handler), opdata);
opdata->failed_primary_text = g_strdup (failed_primary_text);
@@ -139,20 +138,20 @@ string_last_line (const gchar *str)
};
-/* Frees a NautilusWipeOperationData structure */
+/* Frees a NwOperationData structure */
static void
diff --git a/nautilus-wipe/path-list.c b/nautilus-wipe/nw-path-list.c
similarity index 88%
rename from nautilus-wipe/path-list.c
rename to nautilus-wipe/nw-path-list.c
index 5f11ebb..4380c30 100644
--- a/nautilus-wipe/path-list.c
+++ b/nautilus-wipe/nw-path-list.c
@@ -23,7 +23,7 @@
# include "config.h"
#endif
-#include "path-list.h"
+#include "nw-path-list.h"
#include <string.h>
#include <glib.h>
@@ -73,7 +73,7 @@ get_desktop_path (void)
* this is different from getting if GFile then getting the path since it tries
* handle x-nautilus-desktop */
gchar *
-nautilus_wipe_path_from_nfi (NautilusFileInfo *nfi)
+nw_path_from_nfi (NautilusFileInfo *nfi)
{
GFile *file;
gchar *path;
@@ -91,16 +91,16 @@ nautilus_wipe_path_from_nfi (NautilusFileInfo *nfi)
/* frees a list of paths */
void
-nautilus_wipe_path_list_free (GList *paths)
+nw_path_list_free (GList *paths)
{
g_list_foreach (paths, (GFunc) g_free, NULL);
g_list_free (paths);
}
/* copies a list of paths
* free the returned list with nautilus_wipe_path_list_free() */
GList *
-nautilus_wipe_path_list_copy (GList *src)
+nw_path_list_copy (GList *src)
{
GList *paths = NULL;
@@ -114,12 +114,12 @@ nautilus_wipe_path_list_copy (GList *src)
}
/* converts a list of #NautilusFileInfo to a list of paths.
* free the returned list with nautilus_wipe_path_list_free()
*
* Returns: The list of paths on success, or %NULL on failure. This function
* will always fail on non-local-mounted (then without paths) files */
GList *
-nautilus_wipe_path_list_new_from_nfi_list (GList *nfis)
+nw_path_list_new_from_nfi_list (GList *nfis)
{
gboolean success = TRUE;
GList *paths = NULL;
@@ -127,7 +127,7 @@ nautilus_wipe_path_list_new_from_nfi_list (GList *nfis)
while (nfis && success) {
gchar *path;
- path = nautilus_wipe_path_from_nfi (nfis->data);
+ path = nw_path_from_nfi (nfis->data);
if (path) {
paths = g_list_prepend (paths, path);
} else {
@@ -136,7 +136,7 @@ nautilus_wipe_path_list_new_from_nfi_list (GList *nfis)
nfis = g_list_next (nfis);
}
if (! success) {
- nautilus_wipe_path_list_free (paths);
+ nw_path_list_free (paths);
paths = NULL;
} else {
paths = g_list_reverse (paths);
@@ -91,16 +91,16 @@ nautilus_wipe_path_from_nfi (NautilusFileInfo *nfi)
}
/* copies a list of paths
- * free the returned list with nautilus_wipe_path_list_free() */
+ * free the returned list with nw_path_list_free() */
GList *
@@ -114,12 +114,12 @@ nautilus_wipe_path_list_copy (GList *src)
}
/* converts a list of #NautilusFileInfo to a list of paths.
- * free the returned list with nautilus_wipe_path_list_free()
+ * free the returned list with nw_path_list_free()
*
* Returns: The list of paths on success, or %NULL on failure. This function
--
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-privacy/packages/nautilus-wipe.git
More information about the Pkg-privacy-commits
mailing list